@@ -6,15 +6,15 @@ from django.utils.decorators import method_decorator
 from django.conf import settings
 
 from .utils.directory_tree import DirectoryTree
+from .utils.decorators import super_user_active_only
 
+
+@method_decorator(login_required, name='dispatch')
+@method_decorator(super_user_active_only, name='dispatch')
 class DirectoryTreeView(TemplateView):
 
     template_name = 'directory_tree/index.html'
 
-    @method_decorator(login_required)
-    def dispatch(self, *args, **kwargs):
-        return super().dispatch(*args, **kwargs)
-
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
 
